{add me to th delphi component}

unit Reg_imag;

interface

uses
  SysUtils, WinTypes, WinProcs, Messages, Classes, Graphics, Forms, Controls,
  extctrls, StdCtrls, DLL_LINK, dialogs, menus;


type
  TMultiImage = class(TGraphicControl)
  private
    FPicture            : TPicture;
    FAutoSize           : Boolean;
    FStretch            : Boolean;
    FCenter             : Boolean;
    FReserved           : Byte;
    FFilename           : String;
    Fdither             : byte;
    FResolution         : byte;
    FSaveQuality        : byte;
    FSaveSmooth         : byte;
    FSaveFileName       : TFileName;
    temps               : String;
    function GetCanvas: TCanvas;
    procedure PictureChanged(Sender: TObject);
    procedure SetAutoSize(Value: Boolean);
    procedure SetCenter(Value: Boolean);
    procedure SetPicture(Value: TPicture);
    procedure SetStretch(Value: Boolean);
  protected
    function GetPalette: HPALETTE; override;
  public
    constructor Create(AOwner: TComponent); override;
    destructor Destroy; override;
    property Canvas: TCanvas read GetCanvas;
    function GetMultiBitmap : String;
    Procedure WriteMultiName(Name : String);
    function GetDither : Byte;
    procedure SetDither(dith : Byte);
    function GetRes : Byte;
    procedure SetRes(res : Byte);
    procedure Paint; override;
    function GetSmooth : Byte;
    procedure SetSmooth(smooth : Byte);
    function GetQuality : Byte;
    procedure SetQuality(Quality : Byte);
    function GetSaveFileName : TFilename;
    procedure SetSaveFileName(fn : TFilename);
    procedure SaveAsJpg(FN : String);
  published
    property Align;
    property AutoSize: Boolean read FAutoSize write SetAutoSize default False;
    property Center: Boolean read FCenter write SetCenter default False;
    property DragCursor;
    property DragMode;
    property Enabled;
    property JPegDither : Byte read GetDither write SetDither;
    property JPegResolution : Byte read GetRes write SetRes;
    property Picture: TPicture read FPicture write SetPicture;
    property JPegSaveQuality : Byte read GetQuality write SetQuality;
    property JPegSaveSmooh : Byte read GetSmooth write SetSmooth;
    property JPegSaveFileName : TFileName read GetSaveFileName write SetSaveFileName;
    property ImageName  : String read GetMultiBitmap write WriteMultiName;
    property ParentShowHint;
    property PopupMenu;
    property ShowHint;
    property Stretch: Boolean read FStretch write SetStretch default False;
    property Visible;
    property OnClick;
    property OnDblClick;
    property OnDragDrop;
    property OnDragOver;
    property OnEndDrag;
    property OnMouseDown;
    property OnMouseMove;
    property OnMouseUp;
  end;



procedure Register;

{------------------------------------------------------------------------}
implementation
uses consts;

{------------------------------------------------------------------------}
procedure Register;
begin
  RegisterComponents('IMAGES',[TMultiImage]);
end;

{------------------------------------------------------------------------

 TMultiImage.

------------------------------------------------------------------------}

constructor TMultiImage.Create(AOwner: TComponent);
begin
  inherited Create(AOwner);
  FPicture := TPicture.Create;
  FPicture.OnChange := PictureChanged;
  FFilename:='';
  Picture.Graphic := nil;
  Height := 105;
  Width := 105;
 end;
{------------------------------------------------------------------------}


destructor TMultiImage.Destroy;
begin
  FPicture.Free;
  inherited Destroy;
end;
{------------------------------------------------------------------------}

function TMultiImage.GetPalette: HPALETTE;
begin
  Result := 0;
  if FPicture.Graphic is TBitmap then
    Result := TBitmap(FPicture.Graphic).Palette;
end;
{------------------------------------------------------------------------}

procedure TMultiImage.Paint;
var
  Dest: TRect;
begin
  if csDesigning in ComponentState then
    with inherited Canvas do
    begin
      Pen.Style := psDash;
      Brush.Style := bsClear;
      Rectangle(0, 0, Width, Height);
    end;
  if Stretch then
    Dest := ClientRect
  else if Center then
    Dest := Rect((Width - Picture.Width) div 2, (Height - Picture.Height) div 2,
      Picture.Width, Picture.Height)
  else
    Dest := Rect(0, 0, Picture.Width, Picture.Height);
  with inherited Canvas do
    StretchDraw(Dest, Picture.Graphic);
end;
{------------------------------------------------------------------------}

function TMultiImage.GetCanvas: TCanvas;
var
  Bitmap: TBitmap;
begin
  if Picture.Graphic = nil then
  begin
    Bitmap := TBitmap.Create;
    try
      Bitmap.Width := Width;
      Bitmap.Height := Height;
      Picture.Graphic := Bitmap;
    finally
      Bitmap.Free;
    end;
  end;
  if Picture.Graphic is TBitmap then
    Result := TBitmap(Picture.Graphic).Canvas
  else
    raise EInvalidOperation.Create(LoadStr(SImageCanvasNeedsBitmap));
end;
{------------------------------------------------------------------------}

procedure TMultiImage.SetAutoSize(Value: Boolean);
begin
  FAutoSize := Value;
  PictureChanged(Self);
end;
{------------------------------------------------------------------------}

procedure TMultiImage.SetCenter(Value: Boolean);
begin
  if FCenter <> Value then
  begin
    FCenter := Value;
    Invalidate;
  end;
end;
{------------------------------------------------------------------------}

procedure TMultiImage.SetPicture(Value: TPicture);
begin
  FPicture.Assign(Value);
end;
{------------------------------------------------------------------------}

procedure TMultiImage.SetStretch(Value: Boolean);
begin
  FStretch := Value;
  Invalidate;
end;
{------------------------------------------------------------------------}

procedure TMultiImage.PictureChanged(Sender: TObject);
begin
  if AutoSize and (Picture.Width > 0) and (Picture.Height > 0) then
    SetBounds(Left, Top, Picture.Width, Picture.Height);
  if (Picture.Graphic is TBitmap) and (Picture.Width = Width) and
    (Picture.Height = Height) then
    ControlStyle := ControlStyle + [csOpaque] else
    ControlStyle := ControlStyle - [csOpaque];
  Invalidate;
end;
{------------------------------------------------------------------------}

function TMultiImage.GetDither : Byte;
begin
  GetDither:=Fdither
end;
{------------------------------------------------------------------------}

procedure TMultiImage.SetDither(dith : Byte);
begin
  Fdither:=4;

  case dith of
            0..4 :Fdither:=dith;
  end;

end;
{------------------------------------------------------------------------}

function TMultiImage.GetRes : Byte;
begin
  GetRes:=FResolution;
end;
{------------------------------------------------------------------------}


procedure TMultiImage.SetRes(res : Byte);
begin
  FResolution:=8;

  case res of
            4 :FResolution:=res;
            8 :FResolution:=res;
            24 :FResolution:=res;
  end;

end;

{------------------------------------------------------------------------}

Procedure TMultiImage.WriteMultiName(Name : String);
begin
  FFilename:=Name;
  GetMultiBitmap;
end;
{------------------------------------------------------------------------}


function TMultiImage.GetMultiBitmap :  String;
var bitmap     : TBitMap;
    Pextension : string[4];

begin

  if not FileExists(FFilename) then begin
     GetMultiBitmap:='file not exits';
     temps:='file not exits';
     Picture.Graphic := nil;
     exit;
  end;

  Pextension:=UpperCase(ExtractFileExt(FFilename));

  if FResolution <> 4 then
  if FResolution <> 8 then
  if FResolution <> 24 then
   FResolution:=8;

  if FDither <> 0 then
  if FDither <> 1 then
  if FDither <> 2 then
  if FDither <> 3 then
  if FDither <> 4 then
    FDither:=4;


  if (Pextension =  '.BMP') or (Pextension =  '.WMF') or (Pextension =  '.ICO') then begin
    Picture.LoadFromFile(FFilename);
    GetMultiBitmap:='Non JPeg,GIF or PCX Image';
    temps:='Non JPeg,GIF or PCX Image';
    exit;
  end;

 if (UpperCase(FFilename) = temps) and (Picture.Bitmap <> nil) then begin
     GetMultiBitmap:=UpperCase(FFilename);
     exit;
  end;

    if Pextension = '.GIF' then begin
     try
      Bitmap := TBitmap.Create;
      Giffile(FFileName, Bitmap); {DLL CALL}
    except
     Picture.Graphic := nil;
     Bitmap.Free;
     temps:=UpperCase(FFilename);
     GetMultiBitmap:=UpperCase(FFilename);
     exit;
    end;
      Picture.Graphic:=Bitmap;
      Bitmap.Free;
   end;

   if Pextension = '.PCX' then begin
     try
      Bitmap := TBitmap.Create;
      PCXfile(FFileName, Bitmap); {DLL CALL}
    except
     Picture.Graphic := nil;
     Bitmap.Free;
     temps:=UpperCase(FFilename);
     GetMultiBitmap:=UpperCase(FFilename);
     exit;
    end;
      Picture.Graphic:=Bitmap;
      Bitmap.Free;
   end;

   if Pextension = '.JPG' then begin
    try
      Bitmap := TBitmap.Create;
      jpgfile(FFilename, FResolution, Fdither, Bitmap);
    except
     Picture.Graphic := nil;
     Bitmap.Free;
     temps:=UpperCase(FFilename);
     GetMultiBitmap:=UpperCase(FFilename);
     exit;
    end;
      Picture.Graphic:=Bitmap;
      Bitmap.Free;
   end;

    temps:=UpperCase(FFilename);
    GetMultiBitmap:=UpperCase(FFilename);
end;

{------------------------------------------------------------------------}

function TMultiImage.GetSmooth : Byte;
begin
  GetSmooth:=FSaveSmooth;
end;

{------------------------------------------------------------------------}
procedure TMultiImage.SetSmooth(smooth : Byte);
begin
{ 1..100, or 0 for no input smoothing }

  if (Smooth > 100) or (Smooth < 0) then FSaveSmooth:=5 else
   FSaveSmooth:=Smooth;
end;

{------------------------------------------------------------------------}

function TMultiImage.GetQuality : Byte;
begin
  GetQuality:=FSaveQuality;
end;
{------------------------------------------------------------------------}

procedure TMultiImage.SetQuality(Quality : Byte);
begin
{ 1..100, for quality}

  if (Quality > 100) OR (Quality < 1) then FSaveQuality:=25 else
   FSaveQuality:=Quality;
end;
{------------------------------------------------------------------------}

function TMultiImage.GetSaveFileName : TFilename;
begin
  GetSaveFileName:=FSaveFileName;
end;

{------------------------------------------------------------------------}

procedure TMultiImage.SetSaveFileName(fn : TFilename);
begin
 if fn <> '' then
   FSaveFileName:=fn
 else
   FSaveFileName:='';
end;
{------------------------------------------------------------------------}

procedure TMultiImage.SaveAsJpg(FN : String);
begin
   if fn <> '' then FSaveFileName:=FN;
  try
    putjpgfile(FSaveFileName, FSaveQuality, FSaveSmooth, picture.Bitmap);
  except

  end;
end;
{------------------------------------------------------------------------


{------------------------------------------------------------------------}
{no Initialization Block}
{------------------------------------------------------------------------}
end.

